import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:graphql_flutter/graphql_flutter.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';

final graphQLClientProvider =
    StateNotifierProvider((ref) => GraphQLClientState());

class GraphQLClientState extends StateNotifier<GraphQLClient> {
  GraphQLClientState() : super(null);

  void setClient(GraphQLClient client) {
    state = client;
  }
}

String uuidFromObject(Object object) {
  if (object is Map<String, Object>) {
    final String typeName = object['__typename'] as String;
    final String id = object['id'].toString();
    if (typeName != null && id != null) {
      return <String>[typeName, id].join('/');
    }
  }
  return null;
}

class GraphQLHooksProvider extends HookWidget {
  GraphQLHooksProvider({
    @required this.child,
    @required this.clientBuilder,
    this.provider,
  });

  final Widget child;
  final Function clientBuilder;
  final StateNotifierProvider<GraphQLClientState> provider;

  @override
  Widget build(BuildContext context) {
    var gql_client = useProvider(provider ?? graphQLClientProvider);
    gql_client.setClient(clientBuilder());

    return child;
  }
}
